@@ -34,11 +34,11 @@ void	    editor_init				(void);
 /* Grid and snap settings */
 gboolean    editor_get_show_grid		(void);
 void	    editor_set_show_grid		(gboolean            show);
-void	    editor_show_grid_settings_dialog	(void);
+void	    editor_show_grid_settings_dialog	(GtkWidget	    *widget);
 
 gboolean    editor_get_snap_to_grid		(void);
 void	    editor_set_snap_to_grid		(gboolean            snap);
-void	    editor_show_snap_settings_dialog	(void);
+void	    editor_show_snap_settings_dialog	(GtkWidget	    *widget);
 
 /* Signal handlers */
 gint	    editor_close_window			(GtkWidget	    *widget,
@@ -93,6 +93,10 @@ gint	    editor_clear_selection		(GtkWidget	    *leave_widget);
 void	    editor_remove_widget_from_selection	(GtkWidget	    *widget);
 void	    editor_deselect_all_placeholders	(void);
 
+/* Called when a GbWidget is destroyed so the editor can remove any references
+   to it. */
+void	    editor_on_widget_destroyed		(GtkWidget	    *widget);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
