@@ -884,7 +884,7 @@ gb_button_set_stock_icon (GtkWidget *widget,
 static void
 gb_button_setup_normal_gnome_dialog_button (GtkWidget *widget)
 {
-  GtkWidget *child, *hbox, *hbox2, *label;
+  GtkWidget *child, *hbox, *hbox2, *label = NULL;
   gboolean existing_label = FALSE;
 
   /* If it is already a standard button, just return. */
