@@ -29,12 +29,15 @@
  */
 static GbWidget gbwidget;
 
+#if 0
 static gchar *Type = "GtkCurve::curve_type";
+#endif
 static gchar *XMin = "GtkCurve::min_x";
 static gchar *XMax = "GtkCurve::max_x";
 static gchar *YMin = "GtkCurve::min_y";
 static gchar *YMax = "GtkCurve::max_y";
 
+#if 0
 static const gchar *GbTypeChoices[] =
 {"Linear", "Spline", "Free", NULL};
 static const gint GbTypeValues[] =
@@ -49,6 +52,7 @@ static const gchar *GbTypeSymbols[] =
   "GTK_CURVE_TYPE_SPLINE",
   "GTK_CURVE_TYPE_FREE"
 };
+#endif
 
 /******
  * NOTE: To use these functions you need to uncomment them AND add a pointer
@@ -77,7 +81,9 @@ gb_curve_new (GbWidgetNewData * data)
 static void
 gb_curve_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 {
+#if 0
   property_add_choice (Type, _("Type:"), _("The type of the curve"), GbTypeChoices);
+#endif
   property_add_float (XMin, _("X Min:"), _("The minimum horizontal value"));
   property_add_float (XMax, _("X Max:"), _("The maximum horizontal value"));
   property_add_float (YMin, _("Y Min:"), _("The minimum vertical value"));
@@ -93,6 +99,7 @@ gb_curve_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 static void
 gb_curve_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 {
+#if 0
   gint i;
 
   for (i = 0; i < sizeof (GbTypeValues) / sizeof (GbTypeValues[0]); i++)
@@ -100,6 +107,7 @@ gb_curve_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       if (GbTypeValues[i] == GTK_CURVE (widget)->curve_type)
 	gb_widget_output_choice (data, Type, i, GbTypeSymbols[i]);
     }
+#endif
   gb_widget_output_float (data, XMin, GTK_CURVE (widget)->min_x);
   gb_widget_output_float (data, XMax, GTK_CURVE (widget)->max_x);
   gb_widget_output_float (data, YMin, GTK_CURVE (widget)->min_y);
@@ -115,11 +123,13 @@ gb_curve_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 static void
 gb_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
-  gint i;
-  gchar *type;
   gfloat min_x, max_x, min_y, max_y;
   gboolean set_range = FALSE;
 
+#if 0
+  gchar *type;
+  gint i;
+
   type = gb_widget_input_choice (data, Type);
   if (data->apply)
     {
@@ -133,6 +143,7 @@ gb_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 	    }
 	}
     }
+#endif
 
   min_x = gb_widget_input_float (data, XMin);
   if (data->apply)
@@ -187,8 +198,10 @@ gb_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 static void
 gb_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 {
-  gint i;
   GtkCurve *curve = GTK_CURVE (widget);
+#if 0
+  gint i;
+#endif
 
   if (data->create_widget)
     {
@@ -197,6 +210,7 @@ gb_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   gb_widget_write_standard_source (widget, data);
 
+#if 0
   if (curve->curve_type != GTK_CURVE_TYPE_SPLINE)
     {
       for (i = 0; i < sizeof (GbTypeValues) / sizeof (GbTypeValues[0]); i++)
@@ -207,6 +221,7 @@ gb_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 			data->wname, GbTypeSymbols[i]);
 	}
     }
+#endif
 
   source_add (data, "  gtk_curve_set_range (GTK_CURVE (%s), %g, %g, %g, %g);\n",
 	      data->wname, curve->min_x, curve->max_x,
