@@ -30,12 +30,15 @@
  */
 static GbWidget gbwidget;
 
+#if 0
 static gchar *Type = "GammaCurve|GtkCurve::curve_type";
+#endif
 static gchar *XMin = "GammaCurve|GtkCurve::min_x";
 static gchar *XMax = "GammaCurve|GtkCurve::max_x";
 static gchar *YMin = "GammaCurve|GtkCurve::min_y";
 static gchar *YMax = "GammaCurve|GtkCurve::max_y";
 
+#if 0
 static const gchar *GbTypeChoices[] =
 {"Linear", "Spline", "Free", NULL};
 static const gint GbTypeValues[] =
@@ -50,7 +53,7 @@ static const gchar *GbTypeSymbols[] =
   "GTK_CURVE_TYPE_SPLINE",
   "GTK_CURVE_TYPE_FREE"
 };
-
+#endif
 
 /******
  * NOTE: To use these functions you need to uncomment them AND add a pointer
@@ -81,8 +84,10 @@ static void
 gb_gamma_curve_create_properties (GtkWidget * widget, GbWidgetCreateArgData *
 				  data)
 {
+#if 0
   property_add_choice (Type, _("Initial Type:"), _("The initial type of the curve"),
 		       GbTypeChoices);
+#endif
   property_add_float (XMin, _("X Min:"), _("The minimum horizontal value"));
   property_add_float (XMax, _("X Max:"), _("The maximum horizontal value"));
   property_add_float (YMin, _("Y Min:"), _("The minimum vertical value"));
@@ -99,6 +104,8 @@ static void
 gb_gamma_curve_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 {
   GtkCurve *curve = GTK_CURVE (GTK_GAMMA_CURVE (widget)->curve);
+
+#if 0
   gint i;
 
   for (i = 0; i < sizeof (GbTypeValues) / sizeof (GbTypeValues[0]); i++)
@@ -106,6 +113,7 @@ gb_gamma_curve_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       if (GbTypeValues[i] == curve->curve_type)
 	gb_widget_output_choice (data, Type, i, GbTypeSymbols[i]);
     }
+#endif
   gb_widget_output_float (data, XMin, curve->min_x);
   gb_widget_output_float (data, XMax, curve->max_x);
   gb_widget_output_float (data, YMin, curve->min_y);
@@ -122,11 +130,13 @@ static void
 gb_gamma_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
   GtkCurve *curve = GTK_CURVE (GTK_GAMMA_CURVE (widget)->curve);
-  gint i;
-  gchar *type;
   gfloat min_x, max_x, min_y, max_y;
   gboolean set_range = FALSE;
 
+#if 0
+  gint i;
+  gchar *type;
+
   type = gb_widget_input_choice (data, Type);
   if (data->apply)
     {
@@ -140,6 +150,7 @@ gb_gamma_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 	    }
 	}
     }
+#endif
 
   min_x = gb_widget_input_float (data, XMin);
   if (data->apply)
@@ -194,8 +205,10 @@ gb_gamma_curve_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 static void
 gb_gamma_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 {
-  gint i;
   GtkCurve *curve = GTK_CURVE (GTK_GAMMA_CURVE (widget)->curve);
+#if 0
+  gint i;
+#endif
 
   if (data->create_widget)
     {
@@ -204,6 +217,7 @@ gb_gamma_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   gb_widget_write_standard_source (widget, data);
 
+#if 0
   if (curve->curve_type != GTK_CURVE_TYPE_SPLINE)
     {
       for (i = 0; i < sizeof (GbTypeValues) / sizeof (GbTypeValues[0]); i++)
@@ -213,6 +227,7 @@ gb_gamma_curve_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 			data->wname, GbTypeSymbols[i]);
 	}
     }
+#endif
 
   source_add (data, "  gtk_curve_set_range (GTK_CURVE (GTK_GAMMA_CURVE (%s)->curve), %g, %g, %g, %g);\n",
 	      data->wname, curve->min_x, curve->max_x,
