@@ -177,9 +177,8 @@ show_image_dialog (GbWidgetNewData * data)
   gtk_widget_show (label);
 
   adjustment = gtk_adjustment_new (100, 1, 10000, 1, 5, 10);
-  spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
-  /* save pointer to entry so we can find it easily in the OK handler */
-  gtk_object_set_data (GTK_OBJECT (dialog), "width", spinbutton);
+  spinbutton = glade_util_spin_button_new (GTK_OBJECT (dialog), "width",
+					   GTK_ADJUSTMENT (adjustment), 1, 0);
   gtk_table_attach (GTK_TABLE (table), spinbutton, 1, 7, 0, 1,
 		    GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 5, 5);
   gtk_widget_grab_focus (spinbutton);
@@ -193,9 +192,8 @@ show_image_dialog (GbWidgetNewData * data)
   gtk_widget_show (label);
 
   adjustment = gtk_adjustment_new (100, 1, 10000, 1, 5, 10);
-  spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
-  /* save pointer to entry so we can find it easily in the OK handler */
-  gtk_object_set_data (GTK_OBJECT (dialog), "height", spinbutton);
+  spinbutton = glade_util_spin_button_new (GTK_OBJECT (dialog), "height",
+					   GTK_ADJUSTMENT (adjustment), 1, 0);
   gtk_table_attach (GTK_TABLE (table), spinbutton, 1, 7, 1, 2,
 		    GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 5, 5);
   gtk_widget_show (spinbutton);
