@@ -137,17 +137,13 @@ gb_radio_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       gb_widget_output_child_label (widget, data, Label);
     }
 
-  gb_widget_output_bool (data, State, data->widget_data->flags & GB_ACTIVE);
+  gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
 
   if (!is_toolbar_button)
     {
       gb_widget_output_bool (data, Indicator,
 			     GTK_TOGGLE_BUTTON (widget)->draw_indicator);
-      if (data->action == GB_SHOWING)
-	property_set_sensitive (Indicator, TRUE);
     }
-  else if (data->action == GB_SHOWING)
-    property_set_sensitive (Indicator, FALSE);
 
   /* If we're showing we need to display the list of groups to choose from.
      We walk the tree of widgets in this component, and if a widget is
@@ -159,6 +155,9 @@ gb_radio_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       get_radio_button_groups (gtk_widget_get_toplevel (widget), &groups);
       property_set_combo_strings (Group, groups);
       g_list_free (groups);
+
+      property_set_visible (Icon, is_toolbar_button);
+      property_set_visible (Indicator, !is_toolbar_button);
     }
 
   gb_widget_output_combo (data, Group,
@@ -273,9 +272,9 @@ gb_radio_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), state);
       if (state)
-	data->widget_data->flags |= GB_ACTIVE;
+	data->widget_data->flags |= GLADE_ACTIVE;
       else
-	data->widget_data->flags &= ~GB_ACTIVE;
+	data->widget_data->flags &= ~GLADE_ACTIVE;
     }
 
   indicator = gb_widget_input_bool (data, Indicator);
@@ -460,7 +459,7 @@ gb_radio_button_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data
     }
   gb_widget_write_standard_source (widget, data);
 
-  if (data->widget_data->flags & GB_ACTIVE)
+  if (data->widget_data->flags & GLADE_ACTIVE)
     {
       source_add (data,
 	  "  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (%s), TRUE);\n",
