@@ -111,7 +111,7 @@ gb_radio_menu_item_get_properties (GtkWidget * widget, GbWidgetGetArgData * data
 {
   gb_widget_output_child_label (widget, data, Label);
 
-  gb_widget_output_bool (data, State, data->widget_data->flags & GB_ACTIVE);
+  gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
   gb_widget_output_bool (data, Toggle, GTK_CHECK_MENU_ITEM (widget)->always_show_toggle);
 
   /* If we're showing we need to display the list of groups to choose from.
@@ -183,9 +183,9 @@ gb_radio_menu_item_set_properties (GtkWidget * widget, GbWidgetSetArgData * data
     {
       gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), state);
       if (state)
-	data->widget_data->flags |= GB_ACTIVE;
+	data->widget_data->flags |= GLADE_ACTIVE;
       else
-	data->widget_data->flags &= ~GB_ACTIVE;
+	data->widget_data->flags &= ~GLADE_ACTIVE;
     }
 
   toggle = gb_widget_input_bool (data, Toggle);
@@ -409,7 +409,7 @@ gb_radio_menu_item_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
 
   gb_widget_write_standard_source (widget, data);
 
-  if (data->widget_data->flags & GB_ACTIVE)
+  if (data->widget_data->flags & GLADE_ACTIVE)
     {
       source_add (data,
       "  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (%s), TRUE);\n",
