@@ -28,6 +28,7 @@
 #include <gnome.h>
 
 #include "glade_gnome.h"
+#include "glade_project.h"
 #include "source.h"
 #include "utils.h"
 
@@ -960,8 +961,8 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
   gint stock_item_index;
   gboolean has_child_menu = FALSE;
   GList *tmp_list;
-  GbSignal *activate_signal = NULL;
-  GbAccelerator *activate_accel = NULL;
+  GladeSignal *activate_signal = NULL;
+  GladeAccelerator *activate_accel = NULL;
   gchar *handler = NULL;
 
   source_buffer = gtk_object_get_data (GTK_OBJECT (GTK_WIDGET (widget)->parent), "glade-uiinfo");
@@ -983,7 +984,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
   tmp_list = data->widget_data->signals;
   while (tmp_list)
     {
-      GbSignal *signal = (GbSignal *) tmp_list->data;
+      GladeSignal *signal = (GladeSignal *) tmp_list->data;
       if (!strcmp (signal->name, "activate"))
 	{
 	  activate_signal = signal;
@@ -997,7 +998,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
   tmp_list = data->widget_data->accelerators;
   while (tmp_list)
     {
-      GbAccelerator *accel = (GbAccelerator *) tmp_list->data;
+      GladeAccelerator *accel = (GladeAccelerator *) tmp_list->data;
       if (!strcmp (accel->signal, "activate"))
 	{
 	  activate_accel = accel;
@@ -1138,7 +1139,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
 			     "    %s,\n"
 			     "    %s_menu_uiinfo, NULL, NULL,\n"
 			     "    %s, %s,\n"
-			     "    %s, %s, NULL\n"
+			     "    %s, (GdkModifierType) %s, NULL\n"
 			     "  },\n",
 			     type,
 			     source_make_static_string (label,
@@ -1177,9 +1178,9 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
 				 "  {\n"
 				 "    %s, %s,\n"
 				 "    %s,\n"
-				 "    %s, NULL, NULL,\n"
+				 "    (gpointer) %s, NULL, NULL,\n"
 				 "    %s, %s,\n"
-				 "    %s, %s, NULL\n"
+				 "    %s, (GdkModifierType) %s, NULL\n"
 				 "  },\n",
 				 type,
 				 source_make_static_string (label,
@@ -1224,7 +1225,7 @@ static void
 glade_gnome_write_menu_item_standard_source (GtkMenuItem * widget,
 					     GbWidgetWriteSourceData * data)
 {
-  GbWidgetData *wdata = data->widget_data;
+  GladeWidgetData *wdata = data->widget_data;
   gchar *uiinfo_name, *uiinfo_name_key, *uiinfo_index_key;
   gint uiinfo_index;
 
@@ -1263,12 +1264,12 @@ glade_gnome_write_menu_item_standard_source (GtkMenuItem * widget,
 		  uiinfo_name, uiinfo_index);
     }
 
-  if (GTK_IS_CHECK_MENU_ITEM (widget) && wdata->flags & GB_ACTIVE)
+  if (GTK_IS_CHECK_MENU_ITEM (widget) && wdata->flags & GLADE_ACTIVE)
     source_add (data,
 		"  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (%s_uiinfo[%i].widget), TRUE);\n",
 		uiinfo_name, uiinfo_index);
 
-  if (!(wdata->flags & GB_SENSITIVE))
+  if (!(wdata->flags & GLADE_SENSITIVE))
     source_add (data,
 		"  gtk_widget_set_sensitive (%s_uiinfo[%i].widget, FALSE);\n",
 		uiinfo_name, uiinfo_index);
@@ -1319,7 +1320,8 @@ glade_gnome_write_radio_menu_item_source (GtkMenuItem * widget,
       g_string_sprintfa (source_buffer,
 			 "  {\n"
 			 "    GNOME_APP_UI_RADIOITEMS, NULL, NULL, %s_uiinfo,\n"
-			 "    NULL, NULL, 0, NULL, 0, 0, NULL\n"
+			 "    NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, 0,\n"
+			 "    (GdkModifierType) 0, NULL\n"
 			 "  },\n",
 			 data->real_wname);
 
@@ -1341,9 +1343,9 @@ glade_gnome_write_radio_menu_item_source (GtkMenuItem * widget,
 		     "  {\n"
 		     "    GNOME_APP_UI_ITEM, %s,\n"
 		     "    %s,\n"
-		     "    %s, NULL, NULL,\n"
+		     "    (gpointer) %s, NULL, NULL,\n"
 		     "    GNOME_APP_PIXMAP_NONE, NULL,\n"
-		     "    %s, %s, NULL\n"
+		     "    %s, (GdkModifierType) %s, NULL\n"
 		     "  },\n",
 		     source_make_static_string (label,
 						data->use_gettext),
