@@ -239,10 +239,10 @@ gb_gnome_app_setup_initial_app (GtkWidget *widget)
 	  gtk_object_set_data (GTK_OBJECT (uiinfo->widget), "GbStockIcon",
 			       GINT_TO_POINTER (ToolBarIndices[i]));
 
-	  /* Copy the tooltip to our GbWidgetData struct. */
+	  /* Copy the tooltip to our GladeWidgetData struct. */
 	  if (uiinfo->hint)
 	    {
-	      GbWidgetData *wdata;
+	      GladeWidgetData *wdata;
 
 	      wdata = gtk_object_get_data (GTK_OBJECT (uiinfo->widget),
 					   GB_WIDGET_DATA_KEY);
@@ -318,11 +318,11 @@ gb_gnome_app_setup_menu_items (GnomeUIInfo *uiinfo, gint *indices)
 		}
 	      else
 		{
-		  GbWidgetData *wdata;
-		  GbSignal *signal;
+		  GladeWidgetData *wdata;
+		  GladeSignal *signal;
 		  gchar *start = "on_", *end = "_activate";
 
-		  signal = g_new (GbSignal, 1);
+		  signal = g_new (GladeSignal, 1);
 		  signal->name = g_strdup ("activate");
 		  /* Generate a default handler name. */
 		  signal->handler = g_malloc (strlen (uiinfo->widget->name) + 1
