@@ -188,7 +188,17 @@ gb_gnome_druid_page_start_set_properties (GtkWidget * widget,
 	  image = gdk_imlib_load_image (string);
 	  if (image == NULL)
 	    {
-	      glade_util_show_message_box (_("Couldn't load image from file\n"));
+	      if (data->action == GB_LOADING)
+		{
+		  load_add_error_message_with_tag (data,
+						   GLADE_LINE_PROPERTY,
+						   _("Couldn't load image from file"),
+						   LogoImage, string);
+		}
+	      else
+		{
+		  glade_util_show_message_box (_("Couldn't load image from file\n"), widget);
+		}
 	    }
 	}
       else
@@ -223,7 +233,17 @@ gb_gnome_druid_page_start_set_properties (GtkWidget * widget,
 	  image = gdk_imlib_load_image (string);
 	  if (image == NULL)
 	    {
-	      glade_util_show_message_box (_("Couldn't load image from file\n"));
+	      if (data->action == GB_LOADING)
+		{
+		  load_add_error_message_with_tag (data,
+						   GLADE_LINE_PROPERTY,
+						   _("Couldn't load image from file"),
+						   WatermarkImage, string);
+		}
+	      else
+		{
+		  glade_util_show_message_box (_("Couldn't load image from file\n"), widget);
+		}
 	    }
 	}
       else
