@@ -39,6 +39,7 @@ extern "C" {
 
 /* These are the standard widget property names */
 extern const gchar*	GbName;
+extern const gchar*	GbClass;
 extern const gchar*	GbX;
 extern const gchar*	GbY;
 extern const gchar*	GbWidth;
@@ -339,12 +340,12 @@ void	    property_set_auto_apply	(gboolean	     value);
 
 
 void	    property_clear_accelerators	(void);
-void	    property_add_accelerator	(GbAccelerator	    *accel);
+void	    property_add_accelerator	(GladeAccelerator    *accel);
 gboolean    property_is_accel_clist	(GtkWidget	    *widget);
 GList*      property_get_accelerators	(void);
 
 void	    property_clear_signals	(void);
-void	    property_add_signal		(GbSignal	    *signal);
+void	    property_add_signal		(GladeSignal	    *signal);
 gboolean    property_is_signal_clist	(GtkWidget	    *widget);
 GList*      property_get_signals	(void);
 
